<?php
declare(strict_types=1);

namespace Catequil\Invoice;

use Catequil\Tool\Metadata\MetadataManager;
use Laminas\Hydrator\ReflectionHydrator;
use Laminas\ServiceManager\AbstractFactory\ReflectionBasedAbstractFactory;

/**
 * Class ConfigProvider
 *
 * @package Catequil\Invoice
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/catequil-invoice
 */
final class ConfigProvider
{
    public function __invoke(): array
    {
        return [
            'orm' => [
                'implementations' => [
                    Model\InvoiceInterface::class           => Model\Invoice::class,
                    Model\InvoiceAddressInterface::class    => Model\InvoiceAddress::class,
                    Model\InvoiceItemInterface::class       => Model\InvoiceItem::class,
                    Model\InvoiceOrderInterface::class      => Model\InvoiceOrder::class,
                    Model\InvoicePaymentInterface::class    => Model\InvoicePayment::class,
                ],
                'entity_paths' => [
                    __NAMESPACE__ => __DIR__ . '/Model',
                ],
            ],
            'hydrators' => [
                'aliases' => [
                    Model\Invoice::class        => Hydrator\InvoiceHydrator::class,
                    Model\InvoiceAddress::class => Hydrator\InvoiceAddressHydrator::class,
                    Model\InvoiceItem::class    => Hydrator\InvoiceItemHydrator::class,
                    Model\InvoiceOrder::class   => ReflectionHydrator::class,
                    Model\InvoicePayment::class => Hydrator\InvoicePaymentHydrator::class,
                ],
                'factories' => [
                    Hydrator\InvoiceHydrator::class => ReflectionBasedAbstractFactory::class,
                ],
                'invokables' => [
                    Hydrator\InvoiceAddressHydrator::class,
                    Hydrator\InvoiceItemHydrator::class,
                    Hydrator\InvoicePaymentHydrator::class,
                ],
            ],
            'dependencies' => [
                'aliases' => [
                    Service\InvoiceServiceInterface::class => Service\InvoiceService::class,
                ],
            ],
            MetadataManager::class => [
                'paths' => [
                    __DIR__ . '/Handler',
                ],
            ],
        ];
    }
}