<?php
declare(strict_types=1);

namespace Catequil\Invoice\Model;

use Catequil\Webshop\Model\WebshopInterface;
use DateTime;
use Doctrine\Common\Collections\ArrayCollection;
use Doctrine\Common\Collections\Collection;
use Doctrine\DBAL\Types\Types;
use Doctrine\ORM\Mapping\Column;
use Doctrine\ORM\Mapping\Entity;
use Doctrine\ORM\Mapping\GeneratedValue;
use Doctrine\ORM\Mapping\Id;
use Doctrine\ORM\Mapping\Index;
use Doctrine\ORM\Mapping\JoinColumn;
use Doctrine\ORM\Mapping\ManyToOne;
use Doctrine\ORM\Mapping\OneToMany;
use Doctrine\ORM\Mapping\Table;

/**
 * Class Invoice
 *
 * @package Catequil\Invoice\Model
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/catequil-invoice
 */
#[Entity]
#[Table('invoice', options: ['collate' => 'utf8mb4_croatian_ci'])]
#[Index(fields: ['documentType', 'invoiceNo'], name: 'invoiceNo')]
class Invoice implements InvoiceInterface
{
    //<editor-fold desc="Entity Fields">

    #[Id]
    #[GeneratedValue('AUTO')]
    #[Column(type: Types::BIGINT, options: ['unsigned' => true])]
    protected ?int $id = null;
    #[Column(type: Types::STRING, length: 5)]
    protected string $documentType = '';
    #[ManyToOne(targetEntity: WebshopInterface::class)]
    #[JoinColumn(nullable: false)]
    protected WebshopInterface $webshop;
    #[Column(type: Types::BIGINT)]
    protected int $invoiceNo;
    #[Column(type: Types::DATETIME_MUTABLE)]
    protected DateTime $createdAt;
    #[OneToMany('invoice', InvoiceOrder::class, ['persist'])]
    protected Collection $orders;
    #[Column(type: Types::TEXT, nullable: true)]
    protected string $comment;
    #[Column(type: Types::STRING, length: 3)]
    protected string $currency;
    #[Column(type: Types::FLOAT)]
    protected float $totalWoTax;
    #[Column(type: Types::FLOAT)]
    protected float $total;
    #[Column(type: Types::FLOAT)]
    protected float $tax;
    #[Column(type: Types::STRING)]
    protected string $shipping;
    #[Column(type: Types::BIGINT, nullable: true)]
    protected ?int $shipmentId = null;
    #[Column(type: Types::BLOB, nullable: true)]
    protected mixed $pdf = null;
    #[ManyToOne(InvoiceAddressInterface::class, ['persist'])]
    #[JoinColumn(nullable: false)]
    protected InvoiceAddressInterface $billingAddress;
    #[ManyToOne(InvoiceAddressInterface::class, ['persist'])]
    #[JoinColumn(nullable: false)]
    protected InvoiceAddressInterface $shippingAddress;
    #[OneToMany('invoice', InvoicePaymentInterface::class, ['persist'])]
    protected Collection $payments;
    #[OneToMany('invoice', InvoiceItemInterface::class, ['persist'])]
    protected Collection $items;

    //</editor-fold>

    public function __construct()
    {
        $this->orders = new ArrayCollection();
        $this->billingAddress = new InvoiceAddress();
        $this->shippingAddress = new InvoiceAddress();
        $this->payments = new ArrayCollection();
        $this->items = new ArrayCollection();
    }

    //<editor-fold desc="Getters & Setters">

    public function getId(): int
    {
        return $this->id;
    }

    public function getCreatedAt(): DateTime
    {
        return $this->createdAt;
    }

    public function getDocumentType(): string
    {
        return $this->documentType;
    }

    public function getInvoiceNo(): int
    {
        return $this->invoiceNo;
    }

    public function getItems(): Collection|array
    {
        return $this->items;
    }

    public function getOrders(): Collection|array
    {
        return $this->orders;
    }

    public function getPayments(): Collection|array
    {
        return $this->payments;
    }

    public function getShipping(): string
    {
        return $this->shipping;
    }

    public function getShipmentId(): ?int
    {
        return $this->shipmentId;
    }

    public function setShipmentId(?int $shipmentId): void
    {
        $this->shipmentId = $shipmentId;
    }

    public function getShippingAddress(): InvoiceAddressInterface
    {
        return $this->shippingAddress;
    }

    public function getWebshop(): WebshopInterface
    {
        return $this->webshop;
    }

    //</editor-fold>
}