<?php
declare(strict_types=1);

namespace Catequil\Invoice\Model;

use Doctrine\DBAL\Types\Types;
use Doctrine\ORM\Mapping\Column;
use Doctrine\ORM\Mapping\Entity;
use Doctrine\ORM\Mapping\GeneratedValue;
use Doctrine\ORM\Mapping\Id;
use Doctrine\ORM\Mapping\Table;
use function trim;

/**
 * Class InvoiceAddress
 *
 * @package Catequil\Invoice\Model
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/catequil-invoice
 */
#[Entity]
#[Table('invoice_address', options: ['collate' => 'utf8mb4_croatian_ci'])]
class InvoiceAddress implements InvoiceAddressInterface
{
    //<editor-fold desc="Entity Fields">

    #[Id]
    #[GeneratedValue('AUTO')]
    #[Column(type: Types::BIGINT, options: ['unsigned' => true])]
    protected int $id = 0;
    #[Column(type: Types::STRING, nullable: true)]
    protected ?string $firstName = null;
    #[Column(type: Types::STRING, nullable: true)]
    protected ?string $lastName = null;
    #[Column(type: Types::STRING, nullable: true)]
    protected ?string $companyName = null;
    #[Column(type: Types::STRING, nullable: true)]
    protected ?string $address1 = null;
    #[Column(type: Types::STRING, nullable: true)]
    protected ?string $address2 = null;
    #[Column(type: Types::STRING, nullable: true)]
    protected ?string $postCode = null;
    #[Column(type: Types::STRING, nullable: true)]
    protected ?string $city = null;
    #[Column(type: Types::STRING, nullable: true)]
    protected ?string $country = null;
    #[Column(type: Types::STRING, nullable: true)]
    protected ?string $emailAddress = null;
    #[Column(type: Types::STRING, nullable: true)]
    protected ?string $phoneNumber = null;

    //</editor-fold>
    //<editor-fold desc="Getters & Setters">

    public function getAddress1(): string
    {
        return $this->address1 ?? '';
    }

    public function getAddress2(): string
    {
        return $this->address2 ?? '';
    }

    public function getCity(): string
    {
        return $this->city ?? '';
    }

    public function getCompanyName(): string
    {
        return $this->companyName ?? '';
    }

    public function getCountry(): string
    {
        return $this->country ?? '';
    }

    public function getEmailAddress(): string
    {
        return $this->emailAddress ?? '';
    }

    public function getFirstName(): string
    {
        return $this->firstName;
    }

    public function getFullName(): string
    {
        return trim($this->firstName . ' ' . $this->lastName);
    }

    public function getLastName(): string
    {
        return $this->lastName;
    }

    public function getPhoneNumber(): string
    {
        return $this->phoneNumber ?? '';
    }

    public function getPostCode(): string
    {
        return $this->postCode ?? '';
    }

    //</editor-fold>
}