<?php
declare(strict_types=1);

namespace Catequil\Invoice\Model;

use Catequil\Webshop\Model\WebshopInterface;
use DateTime;
use Doctrine\Common\Collections\Collection;

/**
 * Interface InvoiceInterface
 *
 * @package Catequil\Invoice\Model
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/catequil-invoice
 */
interface InvoiceInterface
{
    public function getId(): int;
    public function getCreatedAt(): DateTime;
    public function getDocumentType(): string;
    public function getInvoiceNo(): int;
    /**
     * @return Collection|InvoiceItemInterface[]
     */
    public function getItems(): Collection|array;
    /**
     * @return Collection|InvoiceOrderInterface[]
     */
    public function getOrders(): Collection|array;
    /**
     * @return Collection|InvoicePaymentInterface[]
     */
    public function getPayments(): Collection|array;
    public function getShipping(): string;
    public function getShipmentId(): ?int;
    public function setShipmentId(?int $shipmentId): void;
    public function getShippingAddress(): InvoiceAddressInterface;
    public function getWebshop(): WebshopInterface;
}