<?php
declare(strict_types=1);

namespace Catequil\Invoice\Model;

use Doctrine\DBAL\Types\Types;
use Doctrine\ORM\Mapping\Column;
use Doctrine\ORM\Mapping\Entity;
use Doctrine\ORM\Mapping\GeneratedValue;
use Doctrine\ORM\Mapping\Id;
use Doctrine\ORM\Mapping\JoinColumn;
use Doctrine\ORM\Mapping\ManyToOne;
use Doctrine\ORM\Mapping\Table;

/**
 * Class InvoiceItem
 *
 * @package Catequil\Invoice\Model
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/catequil-invoice
 */
#[Entity]
#[Table('invoice_item', options: ['collate' => 'utf8mb4_croatian_ci'])]
class InvoiceItem implements InvoiceItemInterface
{
    //<editor-fold desc="Entity Fields">

    #[Id]
    #[GeneratedValue('AUTO')]
    #[Column(type: Types::BIGINT, options: ['unsigned' => true])]
    protected ?int $id = null;
    #[ManyToOne(InvoiceInterface::class, inversedBy: 'items')]
    #[JoinColumn(nullable: false)]
    protected InvoiceInterface $invoice;
    #[Column(type: Types::SMALLINT)]
    protected int $sortNo = 0;
    #[Column(type: Types::STRING)]
    protected string $sku = '';
    #[Column(type: Types::SMALLINT)]
    protected int $quantity = 0;
    #[Column(type: Types::STRING)]
    protected string $name = '';
    #[Column(type: Types::FLOAT)]
    protected float $regularPrice = 0;
    #[Column(type: Types::FLOAT)]
    protected float $rebate = 0;
    #[Column(type: Types::FLOAT)]
    protected float $total = 0;

    //</editor-fold>
    //<editor-fold desc="Getters & Setters">

    public function getSortNo(): int
    {
        return $this->sortNo;
    }

    public function getSku(): string
    {
        return $this->sku;
    }

    public function getQuantity(): int
    {
        return $this->quantity;
    }

    public function getName(): string
    {
        return $this->name;
    }

    public function getRegularPrice(): float|int
    {
        return $this->regularPrice;
    }

    public function getRebate(): float|int
    {
        return $this->rebate;
    }

    public function getTotal(): float|int
    {
        return $this->total;
    }

    //</editor-fold>
}