<?php
declare(strict_types=1);

namespace CatequilTest\Invoice\Hydrator;

use Catequil\Invoice\Hydrator\InvoiceAddressHydrator;
use Catequil\Invoice\Model\InvoiceAddress;
use Catequil\Invoice\Model\InvoiceAddressInterface;
use Laminas\Hydrator\HydratorInterface;
use PHPUnit\Framework\TestCase;
use function file_get_contents;
use function json_decode;

/**
 * Class InvoiceAddressHydratorTest
 *
 * @package CatequilTest\Invoice\Hydrator
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/catequil-invoice
 */
final class InvoiceAddressHydratorTest extends TestCase
{
    private HydratorInterface $hydrator;

    protected function setUp(): void
    {
        parent::setUp();
        $this->hydrator = new InvoiceAddressHydrator();
    }

    public function testCanHydrateInvoiceAddress()
    {
        $data = json_decode(file_get_contents(__DIR__ . '/../data/invoice1.json'), true);
        $data = $data['Dostava'];

        /** @var InvoiceAddressInterface $address */
        $address = $this->hydrator->hydrate($data, new InvoiceAddress());

        self::assertEquals('Franjo', $address->getFirstName());
        self::assertEquals('Toić', $address->getLastName());
        self::assertEquals('Neka firma', $address->getCompanyName());
        self::assertEquals('Loznati 16', $address->getAddress1());
        self::assertEquals('u dvorištu', $address->getAddress2());
        self::assertEquals('ORLEC (CRES)', $address->getCity());
        self::assertEquals('51557', $address->getPostCode());
        self::assertEquals('HR', $address->getCountry());
        self::assertEquals('franjo.toic@gmail.com', $address->getEmailAddress());
        self::assertEquals('0989629469', $address->getPhoneNumber());
    }
}