<?php
declare(strict_types=1);

namespace CatequilTest\Invoice\Hydrator;

use Catequil\Invoice\ConfigProvider;
use Catequil\Invoice\Hydrator\InvoiceHydrator;
use Catequil\Invoice\Model\Invoice;
use Catequil\Invoice\Model\InvoiceInterface;
use Catequil\Webshop\Model\WebshopInterface;
use Laminas\Hydrator\DelegatingHydrator;
use Laminas\Hydrator\HydratorInterface;
use Laminas\Hydrator\HydratorPluginManager;
use Laminas\ServiceManager\ServiceManager;
use PHPUnit\Framework\TestCase;
use function file_get_contents;
use function json_decode;

/**
 * Class InvoiceHydratorTest
 *
 * @package CatequilTest\Invoice\Hydrator
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/catequil-invoice
 */
final class InvoiceHydratorTest extends TestCase
{
    private HydratorInterface $hydrator;

    protected function setUp(): void
    {
        parent::setUp();

        $config = (new ConfigProvider())();
        $config['dependencies']['services']['config'] = $config;
        $container = new ServiceManager($config['dependencies']);
        $hydrators = new HydratorPluginManager($container, $config['hydrators']);
        $delegatingHydrator = new DelegatingHydrator($hydrators);

        $this->hydrator = new InvoiceHydrator($delegatingHydrator);
    }

    public function testCanHydrateInvoice()
    {
        $data = json_decode(file_get_contents(__DIR__ . '/../data/invoice1.json'), true);
        $data['WebShopSiteName'] = $this->createMock(WebshopInterface::class);

        /** @var InvoiceInterface $invoice */
        $invoice = $this->hydrator->hydrate($data, new Invoice());

        self::assertEquals('WSB', $invoice->getDocumentType());
        self::assertEquals(549, $invoice->getInvoiceNo());
        self::assertEquals('17.05.2022 14:58:35', $invoice->getCreatedAt()->format('d.m.Y G:i:s'));

        self::assertCount(1, $invoice->getOrders());
        self::assertEquals(455791, $invoice->getOrders()[0]->getOrderNo());
    }
}