<?php
declare(strict_types=1);

namespace CatequilTest\Invoice\Hydrator;

use Catequil\Invoice\Hydrator\InvoiceItemHydrator;
use Catequil\Invoice\Model\InvoiceItem;
use Catequil\Invoice\Model\InvoiceItemInterface;
use Laminas\Hydrator\HydratorInterface;
use PHPUnit\Framework\TestCase;
use function file_get_contents;
use function json_decode;

/**
 * Class InvoiceItemHydratorTest
 *
 * @package CatequilTest\Invoice\Hydrator
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/catequil-invoice
 */
final class InvoiceItemHydratorTest extends TestCase
{
    private HydratorInterface $hydrator;

    protected function setUp(): void
    {
        parent::setUp();
        $this->hydrator = new InvoiceItemHydrator();
    }

    public function testCanHydrateInvoiceItem()
    {
        $data = json_decode(file_get_contents(__DIR__ . '/../data/invoice1.json'), true);
        $data = $data['Body'][0];

        /** @var InvoiceItemInterface $item */
        $item = $this->hydrator->hydrate($data, new InvoiceItem());

        self::assertEquals(1, $item->getSortNo());
        self::assertEquals('EPH5W30R-1/1', $item->getSku());
        self::assertEquals('ENEOS Hyper-R 5W30 (1L)', $item->getName());
        self::assertEquals(1, $item->getQuantity());
        self::assertEquals(112, $item->getRegularPrice());
        self::assertEquals(43, $item->getRebate());
        self::assertEquals(63.8375, $item->getTotal());
    }
}